@@ -49,8 +49,11 @@ from pytensor.scan import scan
 
 from pymc.distributions.transforms import _default_transform, log, logodds
 from pymc.logprob.abstract import MeasurableVariable, _logprob
-from pymc.logprob.basic import conditional_logp, logp
+from pymc.logprob.basic import conditional_logp, icdf, logcdf, logp
 from pymc.logprob.transforms import (
+    ArccoshTransform,
+    ArcsinhTransform,
+    ArctanhTransform,
     ChainedTransform,
     CoshTransform,
     ErfcTransform,
@@ -1028,6 +1031,9 @@ def test_multivariate_transform(shift, scale):
         (pt.sinh, SinhTransform()),
         (pt.cosh, CoshTransform()),
         (pt.tanh, TanhTransform()),
+        (pt.arcsinh, ArcsinhTransform()),
+        (pt.arccosh, ArccoshTransform()),
+        (pt.arctanh, ArctanhTransform()),
     ],
 )
 def test_erf_logp(pt_transform, transform):
@@ -1060,6 +1066,9 @@ from tests.distributions.test_transform import check_jacobian_det
         SinhTransform(),
         CoshTransform(),
         TanhTransform(),
+        ArcsinhTransform(),
+        ArccoshTransform(),
+        ArctanhTransform(),
     ],
 )
 def test_check_jac_det(transform):
@@ -1071,3 +1080,37 @@ def test_check_jac_det(transform):
         elemwise=True,
         rv_var=pt.random.normal(0.5, 1, name="base_rv"),
     )
+
+
+def test_logcdf_measurable_transform():
+    x = pt.exp(pt.random.uniform(0, 1))
+    value = x.type()
+    logcdf_fn = pytensor.function([value], logcdf(x, value))
+
+    assert logcdf_fn(0) == -np.inf
+    np.testing.assert_almost_equal(logcdf_fn(np.exp(0.5)), np.log(0.5))
+    np.testing.assert_almost_equal(logcdf_fn(5), 0)
+
+
+def test_logcdf_measurable_non_injective_fails():
+    x = pt.abs(pt.random.uniform(0, 1))
+    value = x.type()
+    with pytest.raises(NotImplementedError):
+        logcdf(x, value)
+
+
+def test_icdf_measurable_transform():
+    x = pt.exp(pt.random.uniform(0, 1))
+    value = x.type()
+    icdf_fn = pytensor.function([value], icdf(x, value))
+
+    np.testing.assert_almost_equal(icdf_fn(1e-16), 1)
+    np.testing.assert_almost_equal(icdf_fn(0.5), np.exp(0.5))
+    np.testing.assert_almost_equal(icdf_fn(1 - 1e-16), np.e)
+
+
+def test_icdf_measurable_non_injective_fails():
+    x = pt.abs(pt.random.uniform(0, 1))
+    value = x.type()
+    with pytest.raises(NotImplementedError):
+        icdf(x, value)
